pub struct LoneHoldConsideration<A, Fx, Rx, D>(_);
Basic consideration method using a fungible balance placed on hold as the cost exacted for the footprint.

NOTE: This is an optimized implementation, which can only be used for systems where each account has only a single active ticket associated with it since individual tickets do not track the specific balance which is frozen. If you are uncertain then use FreezeConsideration instead, since this works in all circumstances.